#
# spec file for package perl-Text-Diff
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Text-Diff
Name:           perl-Text-Diff
Version:        1.450.0
Release:        1.2
# 1.45 -> normalize -> 1.450.0
%define cpan_version 1.45
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perform diffs on files and record sets
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NE/NEILB/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Algorithm::Diff) >= 1.190
Requires:       perl(Algorithm::Diff) >= 1.190
Provides:       perl(Text::Diff) = %{version}
Provides:       perl(Text::Diff::Base)
Provides:       perl(Text::Diff::Config) = 1.440.0
Provides:       perl(Text::Diff::Table) = 1.440.0
%undefine       __perllib_provides
%{perl_requires}

%description
'diff()' provides a basic set of services akin to the GNU 'diff' utility.
It is not anywhere near as feature complete as GNU 'diff', but it is better
integrated with Perl and available on all platforms. It is often faster
than shelling out to a system's 'diff' executable for small files, and
generally slower on larger files.

Relies on Algorithm::Diff for, well, the algorithm. This may not produce
the same exact diff as a system's local 'diff' executable, but it will be a
valid diff and comprehensible by 'patch'. We haven't seen any differences
between Algorithm::Diff's logic and GNU 'diff''s, but we have not examined
them to make sure they are indeed identical.

*Note*: If you don't want to import the 'diff' function, do one of the
following:

   use Text::Diff ();

   require Text::Diff;

That's a pretty rare occurrence, so 'diff()' is exported by default.

If you pass a filename, but the file can't be read, then 'diff()' will
'croak'.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sat May 10 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Sat Aug 19 2017 coolo@suse.com
- updated to 1.45
  see /usr/share/doc/packages/perl-Text-Diff/Changes
  1.45 2017-08-16 NEILB
  - Typo fixed in doc. Patch from Lucas Kanashiro++. RT#112564
  - Documentation improvements PR from David Gutteridge++.
* Tue Mar  8 2016 coolo@suse.com
- updated to 1.44
  see /usr/share/doc/packages/perl-Text-Diff/Changes
  1.44 2016-02-26 NEILB
  - Fixed the handling of text without a trailing newline. This module now
    adds the same text that the diff tool does, "
  \ No newline at end of
    file
  ". Previously this module simply produced broken diffs when one or
    both files had no trailing newline. Fixed by Dave Rolsky. GitHub #1.
* Sun Aug 23 2015 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Text-Diff/Changes
* Tue Jan 10 2012 coolo@suse.com
- regenerate with cpanspec for correct license and source lines
* Sun Apr 17 2011 pascal.bleser@opensuse.org
- update to 1.41:
  * added DIFF_OUTPUT_UNICODE env variable to allow outputting unicode
    characters
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Dec 13 2009 chris@computersalat.de
- cleanup spec
  * fixed header
  * updated desc
  * added LICENSE README to doc
  * moved changelog to .changes
- fixed build-/deps
  * added Data::Dumper
* Mon Jul 27 2009 chris@computersalat.de
- update to 1.37
  * Switching to a production release
  * Switching to a 1.xx version to indicate this
  * Added META.yml file
- 1.36_01 Mon 13 Jul 2009
  * Cleaning this up to pass tests
  * Adding author tests
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Thu Jun 18 2009 chris@computersalat.de
- spec fix for perl-macros
* Thu Jun 18 2009 chris@computersalat.de
- added perl-macros
  o autogen filelist with perl_gen_filelist
* Fri Jun 12 2009 chris@computersalat.de
- spec mods
  o updated header
  o some defines
  o auto filelist gen to make rpmlint happy
* Tue Sep 18 2007 <jfunk@funktronics.ca>
- Initial release 0.35
